# Module 'BBLibc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_BitMap24_ChangeRGBOrder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_Clear(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_GetData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_GetDimension(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromBMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_ReadFromJPEG(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToBMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitMap24_SaveToJPEG(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_ALPHABMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_AUTO_OBJDSCR(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_BITMAP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_BMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_CID_OBJDSCR(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetResourceFile(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetResourceName(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_GetnFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_IsResourceLoaded(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_LoadResourceToMemory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_NResources(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_ResourceManager_SaveResource(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetConfigDirectory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetCurrentLanguage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetResourceManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetnOpenInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetnOpenedInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadAutoBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def LoadResourceToMemory(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadAutoBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadBOD(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ReadMMP(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def RemoveOnOpenInputFileFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def ResetnOpenedInputFiles(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SaveAutoBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SaveBODData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def SetOnOpenInputFileFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BitMap24(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BitMap24(*args: __bt.todo) -> __bt.todo:
    """"""
    ...
