# Module 'B3DLib'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def DiffAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetEntity2EntityAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetXZAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetXZDistance(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetYAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Modulo(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Normalize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Pos2PosXZAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Pos2PosYAngle(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Scale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...
