# Module 'BInputc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_InputAction_AddEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_CurrentlyActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_GetTimeActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_GetnInputEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_IsConst(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_Name(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveAllEvents(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveAllProcs(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_RemoveEvent(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_nInputEvents(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputAction_nProcs(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_Find(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_GetAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_RemoveAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputActions_nElements(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_AddListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_IsBinded(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_RemoveListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputDevice_nListeners(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener_EventCallback(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener_SetPythonFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputListener___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AddInputAction(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AddInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_AssocKey(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_Bind2(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetAttachedDevice(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetInputActions(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetTimeActionActivated(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_GetTimeActionHeld(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_InputManager_SetInputActionsSet(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetDevice(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetKey(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_nInputEvent_GetPress(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def GetInputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_InputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_InputListener(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_InputManager(*args: __bt.todo) -> __bt.todo:
    """"""
    ...
