# Module 'BUIxc'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def B_BarWidget_B_BAR_Backward(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Both(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Expand(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Fordward(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Horizontal(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_B_BAR_Vertical(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetLimits(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_GetValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetLimits(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BarWidget_SetValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitmapWidget_SetBitmap(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_BitmapWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_CreateBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_DestroyBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FontServer_GetBFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetFirst(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetHeight(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetLast(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetPointer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font_GetTextWidth(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Font___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_AddWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidgetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_GetWidget_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetRel(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetRel_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetTo(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_MoveWidgetTo_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RecalcLayout(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RemoveWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_RemoveWidget_Idx(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_FrameWidget_nWidgets(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_AddWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_DefSizeChanged(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_GridWidget_GetWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetBorder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetBorderColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_GetSolid(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmap(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmapCoords(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBitmapIndex(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBorder(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetBorderColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_RectWidget_SetSolid(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_AddBar(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_AddValue(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_Draw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetBar(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_GetnBars(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetMovementMode(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetPositionPercentage(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_StackBarWidget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Horizontal(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_B_TEXT_Vertical(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetAutoSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetJustification(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextOriginX(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_GetTextOriginY(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetAutoSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetBackgroundAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetBackgroundColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetFont(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetJustification(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetOrientation(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetText(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetTextOriginX(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget_SetTextOriginY(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_TextWidget___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AcceptsFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AddAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_AddLabel(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteBottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteLeft(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteRight(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_AbsoluteTop(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_HRelative(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_FR_VRelative(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Bottom(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_HCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Left(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Right(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_Top(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_B_LAB_VCenter(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_DefDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_DefSizeChanged(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetAutoScale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetClipChildren(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetClipDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetHasFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetPointer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetPosition(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_GetVisible(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_MultiplyAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_Name(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_ProcessCommand(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_RecalcLabelLayout(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetAlpha(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetAutoScale(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetClipChildren(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetClipDraw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetColor(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetData(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetDrawFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetHasFocus(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetSize(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetSizeChangedFunc(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget_SetVisible(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def B_Widget___str__(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateFrameWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateNULLWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateRectWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateTextWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def CreateWidgetFromPtr(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def Draw(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_BitmapWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_FontServer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_FrameWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_GridWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_RectWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_StackBarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_TextWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def delete_B_Widget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_BitmapWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_FontServer(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_FrameWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_GridWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_RectWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_StackBarWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_TextWidget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...


def new_B_Widget(*args: __bt.todo) -> __bt.todo:
    """"""
    ...
