# Module 'Traps_C'
from __future__ import annotations

import Bladex.__sub__.b_types as __bt


def AddAllObjects(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddAllPersons(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddName(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def AddSector(*args: __bt.todo) -> __bt.todo:
    """InitSector()
    Funcion para inicializar"""
    ...


def AddSplineNode(*args: __bt.todo) -> __bt.todo:
    """AddSplineNode(spline,pos,tang_i,tang_f)
    Funcion para añadir un nodo al spline"""
    ...


def ClearSpline(*args: __bt.todo) -> __bt.todo:
    """ClearSpline()
    Funcion para borrar los nodos del spline"""
    ...


def CloseSpline(*args: __bt.todo) -> __bt.todo:
    """CloseSpline()
    Funcion para cerrar la spline"""
    ...


def CreateSpline(*args: __bt.todo) -> __bt.todo:
    """CreateSpline()
    Funcion para crear una spline"""
    ...


def DeleteMaxPath(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def GetMaxPathPosition(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def GetSplinePos(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def InitSector(*args: __bt.todo) -> __bt.todo:
    """AddSector()
    Funcion para añadir una nueva habitacion"""
    ...


def IsValidEntity(*args: __bt.todo) -> __bt.todo:
    """SearchSector()
    Funcion para buscar una habitacion"""
    ...


def LoadMaxPath(*args: __bt.todo) -> __bt.todo:
    """GetSplinePos(spline,time)
    Funcion para obtener la posicion de una spline"""
    ...


def Prueba(*args: __bt.todo) -> __bt.todo:
    """ClonarFlecha()
    Funcion para clonar una flecha clavada con el nombre original"""
    ...
